<?php

namespace WPRuby_CAA\Core\Features\Plugins;

use WPRuby_CAA\Core\Helpers\Helper;

class BuddyPress extends Plugin {

	public function name(): string {
		return 'BuddyPress';
	}

	public function key(): string {
		return 'buddypress';
	}

	public function is_installed(): bool {
		return function_exists('bp_is_active');
	}

	public function menu(): array {
		return [
			'settings' => [
				'name' => 'Settings',
				'menu' => [
					[
						'title' => 'Options',
						'slug'  => 'bp-settings'
					],
					[
						'title' => 'Pages',
						'slug'  => 'bp-page-settings'
					],
					[
						'title' => 'Credits',
						'slug'  => 'bp-credits'
					],
				],
			],

			'tools' => [
				'name' => 'Tools',
				'menu' => [
					[
						'title' => 'Manage Invitations',
						'slug'  => 'bp-members-invitations'
					],
					[
						'title' => 'Manage Opt-outs',
						'slug'  => 'bp-optouts'
					],
				],
			],
		];
	}

	public function filter()
	{
		$this->block_pages();
		add_filter('bp_core_get_admin_settings_tabs', [$this, 'filter_settings_tabs']);
		add_filter('bp_core_get_admin_tools_tabs', [$this, 'filter_tools_tabs']);
	}

	public function block_pages()
	{
		global $pagenow;
		if (!in_array($pagenow, ['tools.php', 'options-general.php'])) {
			return;
		}

		if (!isset($_GET['page'])) {
			return;
		}

		$page = sanitize_key($_GET['page']);

		if (in_array($page, $this->items_to_block['settings'])) {
			Helper::block_access();
		}

		if (in_array($page, $this->items_to_block['tools'])) {
			Helper::block_access();
		}
	}

	public function filter_settings_tabs($settings_tabs)
	{
		return $this->filter_tabs('settings', $settings_tabs);
	}

	public function filter_tools_tabs($settings_tabs)
	{
		return $this->filter_tabs('tools', $settings_tabs);
	}

	private function filter_tabs(string $type, $tabs) {
		if(!isset($this->items_to_block[$type])) return $tabs;

		foreach ($tabs as $key => $item) {
			if (in_array($item['id'], $this->items_to_block[$type])) {
				unset($tabs[$key]);
			}
		}

		return $tabs;
	}



}
