<?php

namespace WPRuby_CAA\Core\Migrations;


use WPRuby_CAA\Core\Constants;
use WPRuby_CAA\Core\Dto\User;

class Migration_200 implements Interface_Migration
{

	public function migrate() {

		$this->create_activity_logs_table();
		$this->migrate_old_user_metadata();
		return true;

	}

	private function migrate_old_user_metadata()
	{
		$caaOldUsers = get_users( 'orderby=ID&meta_key=caa_account&meta_value=true' );
		/** @var \WP_User $user */
		foreach ($caaOldUsers as $user){
			$newUser = new User($user->ID);

			// user expiring
			$userExpiring = get_user_meta($user->ID, 'caa_user_expiring', true);
			if ($userExpiring > 0) {
				if ($userExpiring == 15) {
					$userExpiring = 14; // to map to two weeks.
				}
				$userExpiring = $userExpiring * 24; // convert from days to hours.
			}
			$newUser->setExpiringIn($userExpiring);

			// is caa account
			$isCaaAccount = get_user_meta($user->ID, 'caa_account', true);
			$newUser->setIsCaaAccount($isCaaAccount === 'true');

			// account created date
			$caaCreated = get_user_meta($user->ID, 'caa_created', true);
			$newUser->setCreatedAt($caaCreated);

			// is deactivated
			$isDeactivated = get_user_meta($user->ID, 'caa_deactivated', true);
			$newUser->setIsDeactivated($isDeactivated === 'true');

			// hide admin bar
			$hideAdminBar = get_user_meta($user->ID, 'caa_hide_admin_bar', true);
			$newUser->setIsAdminBarHidden($hideAdminBar);


			$newUser->setCreatedBy(get_current_user_id());
			$newUser->setPluginsRestrictedMenu([]);

			$mainMenu = get_user_meta($user->ID, 'caa_main_menu', true);
			$subMenu = get_user_meta($user->ID, 'caa_sub_menu', true);

			$restricted_items = is_array($mainMenu) ? $mainMenu : [];

			if (is_array($subMenu)) {
				$restricted_items = array_merge($subMenu, $restricted_items);
			}

			$newUser->setRestrictedMenu($restricted_items);

		}
	}

	private function create_activity_logs_table()
	{
		global $wpdb;

		$table_name = Constants::activities_table_name();

		$charset_collate = $wpdb->get_charset_collate();
		if ( $wpdb->get_var( "SHOW TABLES LIKE '$table_name'" ) == $table_name ) {
			return;
		}

		$sql = "CREATE TABLE $table_name (
		id bigint(20) NOT NULL AUTO_INCREMENT,
		action varchar(50) NOT NULL,
		user_id bigint(20) unsigned NOT NULL default '0',
		username varchar(50),
		object_id mediumint(50),
		object_type varchar(50),
		object_title varchar(250),
		ip_address varchar(50) NOT NULL,
		created_at datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
		PRIMARY KEY  (id)
	) $charset_collate;";

		require_once ABSPATH . 'wp-admin/includes/upgrade.php';
		dbDelta( $sql );
	}

	/**
	 * @return mixed
	 */
	public function version() {
		return '2.0.0';
	}
}
